ExportSpecifier

Enum ExportSpecifier 

pub enum ExportSpecifier {
    Namespace(ExportNamespaceSpecifier),
    Default(ExportDefaultSpecifier),
    Named(ExportNamedSpecifier),
}

Variants

Implementations

Source

impl ExportSpecifier

pub const fn is_namespace(&self) -> bool

Returns true if self is of variant Namespace.

pub fn as_namespace(&self) -> Option<&ExportNamespaceSpecifier>

Returns Some if self is a reference of variant Namespace, and None otherwise.

pub fn as_mut_namespace(&mut self) -> Option<&mut ExportNamespaceSpecifier>

Returns Some if self is a mutable reference of variant Namespace, and None otherwise.

pub fn expect_namespace(self) -> ExportNamespaceSpecifier
where Self: Debug,

Unwraps the value, yielding the content of Namespace.

Panics

Panics if the value is not Namespace. In debug builds the panic message includes the content of self.

pub fn namespace(self) -> Option<ExportNamespaceSpecifier>

Returns Some if self is of variant Namespace, and None otherwise.

pub const fn is_default(&self) -> bool

Returns true if self is of variant Default.

pub fn as_default(&self) -> Option<&ExportDefaultSpecifier>

Returns Some if self is a reference of variant Default, and None otherwise.

pub fn as_mut_default(&mut self) -> Option<&mut ExportDefaultSpecifier>

Returns Some if self is a mutable reference of variant Default, and None otherwise.

pub fn expect_default(self) -> ExportDefaultSpecifier
where Self: Debug,

Unwraps the value, yielding the content of Default.

Panics

Panics if the value is not Default. In debug builds the panic message includes the content of self.

pub fn default(self) -> Option<ExportDefaultSpecifier>

Returns Some if self is of variant Default, and None otherwise.

pub const fn is_named(&self) -> bool

Returns true if self is of variant Named.

pub fn as_named(&self) -> Option<&ExportNamedSpecifier>

Returns Some if self is a reference of variant Named, and None otherwise.

pub fn as_mut_named(&mut self) -> Option<&mut ExportNamedSpecifier>

Returns Some if self is a mutable reference of variant Named, and None otherwise.

pub fn expect_named(self) -> ExportNamedSpecifier
where Self: Debug,

Unwraps the value, yielding the content of Named.

Panics

Panics if the value is not Named. In debug builds the panic message includes the content of self.

pub fn named(self) -> Option<ExportNamedSpecifier>

Returns Some if self is of variant Named, and None otherwise.