ForHead

Enum ForHead 

pub enum ForHead {
    VarDecl(Box<VarDecl>),
    UsingDecl(Box<UsingDecl>),
    Pat(Box<Pat>),
}
A head for for-in and for-of loop.

Variants



VarDecl(Box<VarDecl>)



UsingDecl(Box<UsingDecl>)



Pat(Box<Pat>)

Implementations

Source

impl ForHead

pub const fn is_var_decl(&self) -> bool

Returns true if self is of variant VarDecl.

pub fn as_var_decl(&self) -> Option<&Box<VarDecl>>

Returns Some if self is a reference of variant VarDecl, and None otherwise.

pub fn as_mut_var_decl(&mut self) -> Option<&mut Box<VarDecl>>

Returns Some if self is a mutable reference of variant VarDecl, and None otherwise.

pub fn expect_var_decl(self) -> Box<VarDecl>
where Self: Debug,

Unwraps the value, yielding the content of VarDecl.

Panics

Panics if the value is not VarDecl. In debug builds the panic message includes the content of self.

pub fn var_decl(self) -> Option<Box<VarDecl>>

Returns Some if self is of variant VarDecl, and None otherwise.

pub const fn is_using_decl(&self) -> bool

Returns true if self is of variant UsingDecl.

pub fn as_using_decl(&self) -> Option<&Box<UsingDecl>>

Returns Some if self is a reference of variant UsingDecl, and None otherwise.

pub fn as_mut_using_decl(&mut self) -> Option<&mut Box<UsingDecl>>

Returns Some if self is a mutable reference of variant UsingDecl, and None otherwise.

pub fn expect_using_decl(self) -> Box<UsingDecl>
where Self: Debug,

Unwraps the value, yielding the content of UsingDecl.

Panics

Panics if the value is not UsingDecl. In debug builds the panic message includes the content of self.

pub fn using_decl(self) -> Option<Box<UsingDecl>>

Returns Some if self is of variant UsingDecl, and None otherwise.

pub const fn is_pat(&self) -> bool

Returns true if self is of variant Pat.

pub fn as_pat(&self) -> Option<&Box<Pat>>

Returns Some if self is a reference of variant Pat, and None otherwise.

pub fn as_mut_pat(&mut self) -> Option<&mut Box<Pat>>

Returns Some if self is a mutable reference of variant Pat, and None otherwise.

pub fn expect_pat(self) -> Box<Pat>
where Self: Debug,

Unwraps the value, yielding the content of Pat.

Panics

Panics if the value is not Pat. In debug builds the panic message includes the content of self.

pub fn pat(self) -> Option<Box<Pat>>

Returns Some if self is of variant Pat, and None otherwise.