pub struct FunctionBody {
pub span: Span,
pub stmts: Vec<Stmt>,
}Expand description
The braced body of a function, method, constructor, or block-bodied arrow function.
Unlike crate::BlockStmt, a function body does not introduce an
additional block scope. Its statements are evaluated in the scope created
by the owning function-like node.
Fields
span: SpanSpan including the braces.
stmts: Vec<Stmt>Trait Implementations
Sourceimpl Clone for FunctionBody
impl Clone for FunctionBody
Sourcefn clone(&self) -> FunctionBody
fn clone(&self) -> FunctionBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionBody
impl Debug for FunctionBody
Sourceimpl Default for FunctionBody
impl Default for FunctionBody
Sourcefn default() -> FunctionBody
fn default() -> FunctionBody
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FunctionBody
impl<'de> Deserialize<'de> for FunctionBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FunctionBody
Sourceimpl EqIgnoreSpan for FunctionBody
impl EqIgnoreSpan for FunctionBody
fn eq_ignore_span(&self, other: &Self) -> bool
Sourceimpl From<FunctionBody> for ArrowFunctionBody
impl From<FunctionBody> for ArrowFunctionBody
Sourcefn from(v: FunctionBody) -> Self
fn from(v: FunctionBody) -> Self
Converts to this type from the input type.
Sourceimpl Hash for FunctionBody
impl Hash for FunctionBody
Sourceimpl PartialEq for FunctionBody
impl PartialEq for FunctionBody
Sourcefn eq(&self, other: &FunctionBody) -> bool
fn eq(&self, other: &FunctionBody) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FunctionBody
impl Serialize for FunctionBody
Sourceimpl Spanned for FunctionBody
impl Spanned for FunctionBody
impl StructuralPartialEq for FunctionBody